@@ -5,6 +5,12 @@ import core.models
 
 
 class Filial(core.models.Log, core.models.EmpresaLog, core.models.EnderecoComplementoLog):
+    """
+    :Nome da classe/função: Filial
+    :descrição: Classe de filiais e suas informações principais
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cd_filial = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=200, null=True)
     nome_completo = models.CharField(max_length=200, null=True)
@@ -18,8 +24,17 @@ class Filial(core.models.Log, core.models.EmpresaLog, core.models.EnderecoComple
         abstract = False
         db_table = 'filial'
 
+    def __str__(self):
+        return self.nome
+
 
 class Servico(core.models.Log):
+    """
+    :Nome da classe/função: Servico
+    :descrição: Classe de serviços possíveis que uma filial pode ofertar
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=200, null=True)
     descricao = models.TextField(null=True)
 
@@ -34,8 +49,17 @@ class Servico(core.models.Log):
         abstract = False
         db_table = 'filial_servico'
 
+    def __str__(self):
+        return self.nome
+
 
 class FilialServico(core.models.Log):
+    """
+    :Nome da classe/função: FilialServico
+    :descrição: Classe de relação de filial com serviços
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     servico = models.ForeignKey('filial.Servico', on_delete=models.DO_NOTHING, null=True)
     cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)
 
@@ -45,6 +69,12 @@ class FilialServico(core.models.Log):
 
 
 class FilialHoraFuncionamento(core.models.Log):
+    """
+    :Nome da classe/função: FilialHoraFuncionamento
+    :descrição: Classe de relação de filial com o seu horário de funcionamento
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     is_padrao = models.BooleanField(null=True, default=True)
     dat_ini_validade = models.DateField(null=True)
     dat_fim_validade = models.DateTimeField(null=True)
