@@ -10,17 +10,52 @@ from django.apps import apps
 
 
 class InteligerQuerySet(models.QuerySet):
+    """
+    :Nome da classe/função: InteligerQuerySet
+    :descrição: Queryset especial da inteliger para salvar logs e desabilitar dados
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     def ativos(self):
+        """
+        :Nome da classe/função: ativos
+        :descrição: Função que retorna apenas os dados com status ativo
+        :Criação: Nícolas Marinoni Grande - 17/08/2020
+        :Edições:
+        :return: Queryset filtrado
+        """
         return self.filter(status=True)
 
     def desabilitar(self, request_=None):
+        """
+        :Nome da classe/função: desabilitar
+        :descrição: Função que desabilita o queryset
+        :Criação: Nícolas Marinoni Grande - 17/08/2020
+        :Edições:
+        :param request_: Informações da requisição
+        :return: Queryset desabilitado
+        """
         usuario = request_.user.id if request_ is not None else None
         qs = self.update(status=False, usr_delete=usuario, dat_delete=timezone.now())
         return qs
 
 
 class InteligerManager(models.Manager):
+    """
+    :Nome da classe/função: InteligerManager
+    :descrição: Manager de queryset para fazer funções na queryset
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     def get_queryset(self):
+        """
+        :Nome da classe/função: get_queryset
+        :descrição: Função que faz a query sobrescrita para ser possível comparar o tempo de pesquisa com o
+                    tempo definido no banco, para salvar log
+        :Criação: Nícolas Marinoni Grande - 17/08/2020
+        :Edições:
+        :return: Queryset processada
+        """
         ini = time.time()
         qs = InteligerQuerySet(self.model)
         fim = time.time()
@@ -35,13 +70,34 @@ class InteligerManager(models.Manager):
         return qs
 
     def ativos(self):
+        """
+        :Nome da classe/função: ativos
+        :descrição: Função que chama a função de ativos do queryset
+        :Criação: Nícolas Marinoni Grande - 17/08/2020
+        :Edições:
+        :return: Função de ativos do queryset
+        """
         return self.get_queryset().ativos()
 
     def desabilitar(self, request_=None):
+        """
+        :Nome da classe/função: desabilitar
+        :descrição: Função que chama a função de desabilitar do queryset
+        :Criação: Nícolas Marinoni Grande - 17/08/2020
+        :Edições:
+        :param request_: Informações da requisição
+        :return: Função de desabilitar do queryset
+        """
         return self.get_queryset().desabilitar(request_=request_)
 
 
 class DatLog(models.Model):
+    """
+    :Nome da classe/função: DatLog
+    :descrição: Classe abstrata para gerar campos padrões das tabelas de log de data
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     dat_insercao = models.DateTimeField(auto_now_add=True, null=True, blank=True)
     dat_edicao = models.DateTimeField(auto_now=True, null=True, blank=True)
     dat_delete = models.DateTimeField(null=True, blank=True)
@@ -52,6 +108,12 @@ class DatLog(models.Model):
 
 
 class UsrLog(models.Model):
+    """
+    :Nome da classe/função: UsrLog
+    :descrição: Classe abstrata para gerar campos padrões das tabelas de log de usuário
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     usr_insercao = models.IntegerField(null=True, blank=True)
     usr_edicao = models.IntegerField(null=True, blank=True)
     usr_delete = models.IntegerField(null=True, blank=True)
@@ -83,6 +145,12 @@ class UsrLog(models.Model):
 
 
 class Log(DatLog, UsrLog):
+    """
+    :Nome da classe/função: Log
+    :descrição: Classe abstrata que herda as classes abstratas de log e sobrescreve atributos de objetos para ser padrão de outras classes
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     normal_objects = models.Manager()
     objects = InteligerManager()
 
@@ -114,6 +182,12 @@ class Log(DatLog, UsrLog):
 
 
 class EmpresaLog(models.Model):
+    """
+    :Nome da classe/função: EmpresaLog
+    :descrição: Classe abstrata que é usada como pai para classes que irão precisar ter distinção de empresas
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     empresa = models.ForeignKey('core.Empresa', on_delete=models.DO_NOTHING, null=True)
 
     class Meta(Log.Meta):
@@ -121,6 +195,12 @@ class EmpresaLog(models.Model):
 
 
 class ContatoLog(models.Model):
+    """
+    :Nome da classe/função: ContatoLog
+    :descrição: Classe abstrata que é usada como pai para classes que irão ter informações de contato
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     celular_numero = models.CharField(max_length=50, null=True)
     celular_ddd = models.CharField(max_length=3, null=True)
     celular_completo = models.CharField(max_length=50, null=True)
@@ -138,6 +218,12 @@ class ContatoLog(models.Model):
 
 
 class PessoaLog(ContatoLog):
+    """
+    :Nome da classe/função: PessoaLog
+    :descrição: Classe abstrata que é usada como pai para classes que irão ter informações de pessoa
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nm_completo = models.CharField(max_length=200, null=True)
     nm_primeiro = models.CharField(max_length=200, null=True)
     nm_ultimo = models.CharField(max_length=200, null=True)
@@ -187,6 +273,12 @@ class PessoaLog(ContatoLog):
 
 
 class EnderecoLog(models.Model):
+    """
+    :Nome da classe/função: EnderecoLog
+    :descrição: Classe abstrata que é usada como pai para classes que irão ter informações de endereço
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cep = models.CharField(max_length=10, null=True)
     cep_form = models.CharField(max_length=15, null=True)
     municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
@@ -197,12 +289,17 @@ class EnderecoLog(models.Model):
     longitude_cep = models.CharField(max_length=200, null=True)
     tipo_cep = models.CharField(max_length=200, null=True)
 
-
     class Meta(Log.Meta):
         abstract = True
 
 
 class EnderecoComplementoLog(models.Model):
+    """
+    :Nome da classe/função: EnderecoComplementoLog
+    :descrição: Classe abstrata que é usada como pai para classes que irão ter informações de complemento de endereço
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cep = models.ForeignKey('core.Cep', null=True, on_delete=models.DO_NOTHING)
     numero = models.CharField(max_length=30, null=True)
     complemento = models.CharField(max_length=100, null=True)
@@ -218,6 +315,12 @@ class EnderecoComplementoLog(models.Model):
 
 
 class Tipo(Log):
+    """
+    :Nome da classe/função: Tipo
+    :descrição: Classe genérica para ser usado para coisas genéricas para todos os projetos
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     codigo = models.IntegerField(null=True)
     tipo = models.CharField(max_length=200, null=True)
     nome = models.CharField(max_length=200, null=True)
@@ -230,6 +333,12 @@ class Tipo(Log):
 
 
 class Empresa(Log):
+    """
+    :Nome da classe/função: Empresa
+    :descrição: Classe que é usada para salvar informações de diferentes empresas
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=100, null=True)
 
     class Meta(Log.Meta):
@@ -238,6 +347,12 @@ class Empresa(Log):
 
 
 class Erro(Log):
+    """
+    :Nome da classe/função: Erro
+    :descrição: Classe que mapeia os tipos de erros possíveis no backend
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     nome = models.CharField(max_length=100)
     codigo = models.CharField(max_length=200, null=True)
     descricao = models.TextField(null=True)
@@ -248,6 +363,12 @@ class Erro(Log):
 
 
 class Data(Log):
+    """
+    :Nome da classe/função: Data
+    :descrição: Classe de datas e informações sobre elas
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     anomesdia = models.IntegerField(primary_key=True)
     anomes = models.IntegerField(null=True)
     ano = models.IntegerField(null=True)
@@ -290,6 +411,12 @@ class Data(Log):
 
 
 class Hora(Log):
+    """
+    :Nome da classe/função: Hora
+    :descrição: Classe de horas e períodos
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     descricao = models.CharField(max_length=200, null=True)
     hora = models.IntegerField(null=True)
     minuto = models.IntegerField(null=True)
@@ -300,8 +427,17 @@ class Hora(Log):
         abstract = False
         db_table = 'hora'
 
+    def __str__(self):
+        return self.hora_minuto
+
 
 class UF(Log):
+    """
+    :Nome da classe/função: UF
+    :descrição: Classe de estados
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     codigo = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=200, null=True)
     nm_abrev = models.CharField(max_length=2, null=True)
@@ -314,6 +450,12 @@ class UF(Log):
 
 
 class Municipio(Log):
+    """
+    :Nome da classe/função: Municipio
+    :descrição: Classe de cidades
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
     codigo = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=200)
@@ -326,6 +468,12 @@ class Municipio(Log):
 
 
 class Cep(Log, EnderecoLog):
+    """
+    :Nome da classe/função: Cep
+    :descrição: Classe de CEPs
+    :Criação: Nícolas Marinoni Grande - 17/08/2020
+    :Edições:
+    """
     cep = models.CharField(max_length=10, primary_key=True)
 
     class Meta(Log.Meta):
